==> qtjambi-qt3dinput-5.15.13-sources.jar: io/qt/qt3d/input/QAnalogAxisInput.java <==
package io.qt.qt3d.input;


/**
 * <p>An axis input controlled by an analog input The axis value is controlled like a traditional analog input such as a joystick</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dinput-qanalogaxisinput.html">Qt3DInput::QAnalogAxisInput</a></p>
 */
public class QAnalogAxisInput extends io.qt.qt3d.input.QAbstractAxisInput
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAnalogAxisInput.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qanalogaxisinput.html#axis-prop">Qt3DInput::QAnalogAxisInput::axisChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="axis")
    public final Signal1<@io.qt.QtPrimitiveType Integer> axisChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAnalogAxisInput(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAnalogAxisInput() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qanalogaxisinput.html#QAnalogAxisInput">Qt3DInput::QAnalogAxisInput::QAnalogAxisInput(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QAnalogAxisInput(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAnalogAxisInput instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qanalogaxisinput.html#axis-prop">Qt3DInput::QAnalogAxisInput::axis()const</a></p>
     */
    @io.qt.QtPropertyReader(name="axis")
    @io.qt.QtUninvokable
    public final int axis(){
        return axis_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int axis_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qanalogaxisinput.html#axis-prop">Qt3DInput::QAnalogAxisInput::setAxis(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="axis")
    public final void setAxis(int axis){
        setAxis_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), axis);
    }
    
    private native void setAxis_native_int(long __this__nativeId, int axis);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAnalogAxisInput(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAnalogAxisInput(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAnalogAxisInput instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dinput-6.4.2-sources.jar: io/qt/qt3d/input/QAnalogAxisInput.java <==
package io.qt.qt3d.input;


/**
 * <p>An axis input controlled by an analog input The axis value is controlled like a traditional analog input such as a joystick</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3dinput-qanalogaxisinput.html">Qt3DInput::QAnalogAxisInput</a></p>
 */
public class QAnalogAxisInput extends io.qt.qt3d.input.QAbstractAxisInput
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAnalogAxisInput.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qanalogaxisinput.html#axis-prop">Qt3DInput::QAnalogAxisInput::axisChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="axis")
    public final Signal1<@io.qt.QtPrimitiveType Integer> axisChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAnalogAxisInput(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAnalogAxisInput() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qanalogaxisinput.html#QAnalogAxisInput">Qt3DInput::QAnalogAxisInput::QAnalogAxisInput(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QAnalogAxisInput(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAnalogAxisInput instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qanalogaxisinput.html#axis-prop">Qt3DInput::QAnalogAxisInput::axis()const</a></p>
     */
    @io.qt.QtPropertyReader(name="axis")
    @io.qt.QtUninvokable
    public final int axis(){
        return axis_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int axis_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qanalogaxisinput.html#axis-prop">Qt3DInput::QAnalogAxisInput::setAxis(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="axis")
    public final void setAxis(int axis){
        setAxis_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), axis);
    }
    
    private native void setAxis_native_int(long __this__nativeId, int axis);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAnalogAxisInput(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAnalogAxisInput(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAnalogAxisInput instance, QDeclarativeConstructor constructor);
    
}
